@@ -53,7 +53,12 @@ class GXDateTime:
         self.dayOfWeek = 0
         if isinstance(value, datetime.datetime):
             if value.tzinfo is None:
-                self.value = datetime.datetime(value.year, value.month, value.day, value.hour, value.minute, value.second, 0, tzinfo=GXTimeZone(int(-time.altzone / 60)))
+                if time.localtime().tm_isdst:
+                    #If DST is used.
+                    tz = GXTimeZone(int(-time.altzone / 60))
+                else:
+                    tz = GXTimeZone(int(-time.timezone / 60))
+                self.value = datetime.datetime(value.year, value.month, value.day, value.hour, value.minute, value.second, 0, tzinfo=tz)
             else:
                 self.value = value
         elif isinstance(value, str):
